class TYPES(object):

    class Charts(object):

        YOUTUBE = "youtube/rankViews/big"
        INSTAGRAM = "instagram/rankLikes/big"
        TWITTER = "twitter/rankLikes/big"
        TWITCH = "twitch/rankViewer/big"
        TIKTOK = "tiktok/rankLikes/big"

        DISPLAY = {
            YOUTUBE: "youtube",
            INSTAGRAM: "instagram",
            TWITTER: "twitter",
            TWITCH: "twitch",
            TIKTOK: "tiktok"
        }